@@ -14,7 +14,7 @@ pub struct JsRuntime {
 }
 
 pub fn v8_init() {
-    let platform = v8::new_default_platform().unwrap();
+    let platform = v8::new_default_platform(0, false).make_shared();
     v8::V8::initialize_platform(platform);
     v8::V8::initialize();
 }
